@@ -1,8 +1,7 @@
-import os
-
 import click
 
-from blackbelt.handle_github import pull_request
+from blackbelt.handle_github import pull_request, merge as do_merge
+
 
 @click.group(help='Handle github-related tasks and integrations.')
 def cli():
@@ -11,4 +10,10 @@ def cli():
 
 @cli.command()
 def pr():
-	pull_request()
+    pull_request()
+
+
+@cli.command()
+@click.argument('pr_url')
+def merge(pr_url):
+    do_merge(pr_url)
