@@ -3,11 +3,10 @@ from paver.setuputils import setup
 
 options = environment.options
 
-from blackbelt.version import VERSION
-
 NAME = 'blackbelt'
-requires = ['click', 'requests', 'trello', 'PyGithub']
+VERSION = '0.6.0'
 
+requires = ['click', 'requests', 'trello', 'PyGithub']
 
 setup(
     name=NAME,
@@ -18,7 +17,7 @@ setup(
     author_email='lukas@apiary.io',
     url='http://github.com/apiaryio/black-belt',
     license='MIT',
-    packages=[NAME, NAME+'.apis', NAME+'.commands'],
+    packages=[NAME, NAME + '.apis', NAME + '.commands'],
     install_requires=requires,
     # requires=requires,
     tests_require=['nose', 'virtualenv'],
@@ -27,7 +26,7 @@ setup(
     # Yes, entry_points are nice and shiny and should be used in 21st century
     # Unfortunately, having some dependencies, the load_entry_point in the ge-
     # nerated console script blows up with pkg_resources.DistributionNotFound: requests
-    # if it was installed with pip. 
+    # if it was installed with pip.
     # Pradoxically, solution is to easy_install -U all the dependencies.
     # Therefore, just fall back to the good, old, simple disutils script that works.
     scripts=['distutils_scripts/bb'],
@@ -62,6 +61,7 @@ def bump(args):
 
     if len(args) > 0 and args[0] == 'major':
         version[1] += 1
+        version[2] = 0
     else:
         version[2] += 1
 
@@ -87,7 +87,23 @@ def bump(args):
     with open(path('docs/source/conf.py'), 'w') as f:
         f.writelines(conf)
 
-    sh("git commit blackbelt/version.py docs/source/conf.py -m 'Version bump to %s'" % '.'.join(version))
+    # bump version in this pavement file itself
+    # we cannot just import it because it implies blackbelt already been
+    # installed/in path, which may cause some interesting problems
+    # solvable by mangling with sys.path, but this just feels...better
+    conf = []
+    with open(path('./pavement.py'), 'r') as f:
+        for line in f.readlines():
+            if line.startswith('VERSION = '):
+                line = "VERSION = '%s'\n" % '.'.join(version)
+
+            conf.append(line)
+
+    with open(path('./pavement.py'), 'w') as f:
+        f.writelines(conf)
+
+    sh("git commit pavement.py blackbelt/version.py docs/source/conf.py -m 'Version bump to %s'" % '.'.join(version))
+
 
 @task
 def release():
